/*
  list.c
  cgi-util demo store
  search for items or browse by category
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <cgi-util.h>
#include "tsv.h"


/* Local function prototype: */

int strhas(char * s1, const char * s2);


/* --- MAIN --- */

int main(int argc, char * argv[])
{
  FILE * fi;
  item_type * item;
  const char * keyword, * category;
  int showed_any;
  
  
  /* Init CGI: */
  
  cgi_init();
  printf("Content-type: text/html\n\n");
  cgi_dump("top.html");
  
  
  /* Check for search and/or browse arguments: */
  
  keyword = cgi_getentrystr("keyword");
  category = cgi_getentrystr("category");
  
  
  if (keyword == NULL &&
      category == NULL)
    {
      /* Nothing entetred - draw a form! */
      
      cgi_dump("search-form.html");
    }
  else
    {
      /* Remind user of their search criteria: */
      
      if (keyword != NULL && strlen(keyword) != 0)
	{
	  printf("Searching for \"<b>%s</b>\"\n", keyword);
	  
	  if (category != NULL && strlen(category) != 0)
	    printf("in the <b>%s</b> category.\n", category);
	  
	  printf("<p>\n");
	}
      else if (category != NULL && strlen(category) != 0)
	{
	  printf("Browsing the <b>%s</b> category.<p>\n", category);
	}
      
      
      /* Open the item file: */
      
      fi = open_item_file("items.tsv");
      
      showed_any = 0;
      
      do
	{
	  item = read_next_item(fi);
	  
	  if (item != NULL)
	    {
	      /* Does the item match our criteria? */
	      
	      if ((keyword == NULL || strlen(keyword) == 0 ||
		   strhas(item->title, keyword) ||
		   strhas(item->description, keyword)) &&
		  (category == NULL || strlen(category) == 0 ||
		   strcmp(item->category, category) == 0))
		{
		  printf("<a href=\"details.cgi?product_id=%s\">%s</a>\n",
			 item->product_id, item->product_id);
		  
		  printf("(%s) - %s -- $%.2f<br>\n",
			 item->category,
			 item->title,
			 item->price);
		  
		  showed_any = 1;
		}
	    }
	}
      while (item != NULL);
      
      
      /* If we didn't show any, apologize: */
      
      if (showed_any == 0)
	{
	  printf("Sorry, no matches found!<p>\n");
	}
      
      
      fclose(fi);
    }
  
  
  /* Close up and quit: */
  
  cgi_dump("bottom.html");
  cgi_quit();
  return(0);
}


/* Like strstr, but case insensitive, and returns a boolean, not a char * */

int strhas(char * s1, const char * s2)
{
  int i;
  char * str1, * str2;
  
  
  /* Duplicate the strings and make them all lowercase: */

  str1 = strdup(s1);
  
  for (i = 0; i < strlen(str1); i++)
    str1[i] = tolower(str1[i]);
  
  str2 = strdup(s2);
  
  for (i = 0; i < strlen(str2); i++)
    str2[i] = tolower(str2[i]);
  
  
  /* Compare: */
  
  if (strstr(str1, str2) != NULL)
    return(1);
  else
    return(0);
}
